==> python2-urwid-1.3.1-2-armv7h.pkg.tar.xz: usr/lib/python2.7/site-packages/urwid/__init__.py <==
#!/usr/bin/python2
#
# Urwid __init__.py - all the stuff you're likely to care about
#
#    Copyright (C) 2004-2012  Ian Ward
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# Urwid web site: http://excess.org/urwid/

from urwid.version import VERSION, __version__
from urwid.widget import (FLOW, BOX, FIXED, LEFT, RIGHT, CENTER, TOP, MIDDLE,
    BOTTOM, SPACE, ANY, CLIP, PACK, GIVEN, RELATIVE, RELATIVE_100, WEIGHT,
    WidgetMeta,
    WidgetError, Widget, FlowWidget, BoxWidget, fixed_size, FixedWidget,
    Divider, SolidFill, TextError, Text, EditError, Edit, IntEdit,
    delegate_to_widget_mixin, WidgetWrapError, WidgetWrap)
from urwid.decoration import (WidgetDecoration, WidgetPlaceholder,
    AttrMapError, AttrMap, AttrWrap, BoxAdapterError, BoxAdapter, PaddingError,
    Padding, FillerError, Filler, WidgetDisable)
from urwid.container import (GridFlowError, GridFlow, OverlayError, Overlay,
    FrameError, Frame, PileError, Pile, ColumnsError, Columns,
    WidgetContainerMixin)
from urwid.wimp import (SelectableIcon, CheckBoxError, CheckBox, RadioButton,
    Button, PopUpLauncher, PopUpTarget)
from urwid.listbox import (ListWalkerError, ListWalker, PollingListWalker,
    SimpleListWalker, SimpleFocusListWalker, ListBoxError, ListBox)
from urwid.graphics import (BigText, LineBox, BarGraphMeta, BarGraphError,
    BarGraph, GraphVScale, ProgressBar, scale_bar_values)
from urwid.canvas import (CanvasCache, CanvasError, Canvas, TextCanvas,
    BlankCanvas, SolidCanvas, CompositeCanvas, CanvasCombine, CanvasOverlay,
    CanvasJoin)
from urwid.font import (get_all_fonts, Font, Thin3x3Font, Thin4x3Font,
    HalfBlock5x4Font, HalfBlock6x5Font, HalfBlockHeavy6x5Font, Thin6x6Font,
    HalfBlock7x7Font)
from urwid.signals import (MetaSignals, Signals, emit_signal, register_signal,
    connect_signal, disconnect_signal)
from urwid.monitored_list import MonitoredList, MonitoredFocusList
from urwid.command_map import (CommandMap, command_map,
    REDRAW_SCREEN, CURSOR_UP, CURSOR_DOWN, CURSOR_LEFT, CURSOR_RIGHT,
    CURSOR_PAGE_UP, CURSOR_PAGE_DOWN, CURSOR_MAX_LEFT, CURSOR_MAX_RIGHT,
    ACTIVATE)
from urwid.main_loop import (ExitMainLoop, MainLoop, SelectEventLoop,
    GLibEventLoop, TornadoEventLoop, AsyncioEventLoop)
try:
    from urwid.main_loop import TwistedEventLoop
except ImportError:
    pass
from urwid.text_layout import (TextLayout, StandardTextLayout, default_layout,
    LayoutSegment)
from urwid.display_common import (UPDATE_PALETTE_ENTRY, DEFAULT, BLACK,
    DARK_RED, DARK_GREEN, BROWN, DARK_BLUE, DARK_MAGENTA, DARK_CYAN,
    LIGHT_GRAY, DARK_GRAY, LIGHT_RED, LIGHT_GREEN, YELLOW, LIGHT_BLUE,
    LIGHT_MAGENTA, LIGHT_CYAN, WHITE, AttrSpecError, AttrSpec, RealTerminal,
    ScreenError, BaseScreen)
from urwid.util import (calc_text_pos, calc_width, is_wide_char,
    move_next_char, move_prev_char, within_double_byte, detected_encoding,
    set_encoding, get_encoding_mode, apply_target_encoding, supports_unicode,
    calc_trim_text, TagMarkupException, decompose_tagmarkup, MetaSuper,
    int_scale, is_mouse_event)
from urwid.treetools import (TreeWidgetError, TreeWidget, TreeNode,
    ParentNode, TreeWalker, TreeListBox)
from urwid.vterm import (TermModes, TermCharset, TermScroller, TermCanvas,
    Terminal)

from urwid import raw_display

==> python2-urwid-2.1.0-1-armv7h.pkg.tar.xz: usr/lib/python2.7/site-packages/urwid/__init__.py <==
#!/usr/bin/python2
#
# Urwid __init__.py - all the stuff you're likely to care about
#
#    Copyright (C) 2004-2012  Ian Ward
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# Urwid web site: http://excess.org/urwid/

from __future__ import division, print_function

from urwid.version import VERSION, __version__
from urwid.widget import (FLOW, BOX, FIXED, LEFT, RIGHT, CENTER, TOP, MIDDLE,
    BOTTOM, SPACE, ANY, CLIP, PACK, GIVEN, RELATIVE, RELATIVE_100, WEIGHT,
    WidgetMeta,
    WidgetError, Widget, FlowWidget, BoxWidget, fixed_size, FixedWidget,
    Divider, SolidFill, TextError, Text, EditError, Edit, IntEdit,
    delegate_to_widget_mixin, WidgetWrapError, WidgetWrap)
from urwid.decoration import (WidgetDecoration, WidgetPlaceholder,
    AttrMapError, AttrMap, AttrWrap, BoxAdapterError, BoxAdapter, PaddingError,
    Padding, FillerError, Filler, WidgetDisable)
from urwid.container import (GridFlowError, GridFlow, OverlayError, Overlay,
    FrameError, Frame, PileError, Pile, ColumnsError, Columns,
    WidgetContainerMixin)
from urwid.wimp import (SelectableIcon, CheckBoxError, CheckBox, RadioButton,
    Button, PopUpLauncher, PopUpTarget)
from urwid.listbox import (ListWalkerError, ListWalker, SimpleListWalker,
    SimpleFocusListWalker, ListBoxError, ListBox)
from urwid.graphics import (BigText, LineBox, BarGraphMeta, BarGraphError,
    BarGraph, GraphVScale, ProgressBar, scale_bar_values)
from urwid.canvas import (CanvasCache, CanvasError, Canvas, TextCanvas,
    BlankCanvas, SolidCanvas, CompositeCanvas, CanvasCombine, CanvasOverlay,
    CanvasJoin)
from urwid.font import (get_all_fonts, Font, Thin3x3Font, Thin4x3Font,
    HalfBlock5x4Font, HalfBlock6x5Font, HalfBlockHeavy6x5Font, Thin6x6Font,
    HalfBlock7x7Font)
from urwid.signals import (MetaSignals, Signals, emit_signal, register_signal,
    connect_signal, disconnect_signal)
from urwid.monitored_list import MonitoredList, MonitoredFocusList
from urwid.command_map import (CommandMap, command_map,
    REDRAW_SCREEN, CURSOR_UP, CURSOR_DOWN, CURSOR_LEFT, CURSOR_RIGHT,
    CURSOR_PAGE_UP, CURSOR_PAGE_DOWN, CURSOR_MAX_LEFT, CURSOR_MAX_RIGHT,
    ACTIVATE)
from urwid.main_loop import (ExitMainLoop, MainLoop, SelectEventLoop,
    GLibEventLoop, TornadoEventLoop, AsyncioEventLoop)
try:
    from urwid.main_loop import TwistedEventLoop
except ImportError:
    pass
try:
    from urwid.main_loop import TrioEventLoop
except ImportError:
    pass
from urwid.text_layout import (TextLayout, StandardTextLayout, default_layout,
    LayoutSegment)
from urwid.display_common import (UPDATE_PALETTE_ENTRY, DEFAULT, BLACK,
    DARK_RED, DARK_GREEN, BROWN, DARK_BLUE, DARK_MAGENTA, DARK_CYAN,
    LIGHT_GRAY, DARK_GRAY, LIGHT_RED, LIGHT_GREEN, YELLOW, LIGHT_BLUE,
    LIGHT_MAGENTA, LIGHT_CYAN, WHITE, AttrSpecError, AttrSpec, RealTerminal,
    ScreenError, BaseScreen)
from urwid.util import (calc_text_pos, calc_width, is_wide_char,
    move_next_char, move_prev_char, within_double_byte, detected_encoding,
    set_encoding, get_encoding_mode, apply_target_encoding, supports_unicode,
    calc_trim_text, TagMarkupException, decompose_tagmarkup, MetaSuper,
    int_scale, is_mouse_event)
from urwid.treetools import (TreeWidgetError, TreeWidget, TreeNode,
    ParentNode, TreeWalker, TreeListBox)
from urwid.vterm import (TermModes, TermCharset, TermScroller, TermCanvas,
    Terminal)

from urwid import raw_display
